@@ -4,14 +4,19 @@ import (
 	"bytes"
 	"testing"
 
-	"github.com/dundee/gdu/analyze"
-	"github.com/dundee/gdu/device"
-	"github.com/dundee/gdu/internal/testanalyze"
-	"github.com/dundee/gdu/internal/testdev"
-	"github.com/dundee/gdu/internal/testdir"
+	log "github.com/sirupsen/logrus"
+
+	"github.com/dundee/gdu/v5/internal/testanalyze"
+	"github.com/dundee/gdu/v5/internal/testdev"
+	"github.com/dundee/gdu/v5/internal/testdir"
+	"github.com/dundee/gdu/v5/pkg/device"
 	"github.com/stretchr/testify/assert"
 )
 
+func init() {
+	log.SetLevel(log.WarnLevel)
+}
+
 func TestAnalyzePath(t *testing.T) {
 	fin := testdir.CreateTestDir()
 	defer fin()
@@ -21,12 +26,42 @@ func TestAnalyzePath(t *testing.T) {
 
 	ui := CreateStdoutUI(output, false, false, false)
 	ui.SetIgnoreDirPaths([]string{"/xxx"})
-	ui.AnalyzePath("test_dir", analyze.ProcessDir, nil)
-	ui.StartUILoop()
+	err := ui.AnalyzePath("test_dir", nil)
+	assert.Nil(t, err)
+	err = ui.StartUILoop()
 
+	assert.Nil(t, err)
 	assert.Contains(t, output.String(), "nested")
 }
 
+func TestAnalyzeSubdir(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	buff := make([]byte, 10)
+	output := bytes.NewBuffer(buff)
+
+	ui := CreateStdoutUI(output, false, false, false)
+	ui.SetIgnoreDirPaths([]string{"/xxx"})
+	err := ui.AnalyzePath("test_dir/nested", nil)
+	assert.Nil(t, err)
+	err = ui.StartUILoop()
+
+	assert.Nil(t, err)
+	assert.Contains(t, output.String(), "file2")
+}
+
+func TestAnalyzePathWithErr(t *testing.T) {
+	buff := make([]byte, 10)
+	output := bytes.NewBuffer(buff)
+
+	ui := CreateStdoutUI(output, false, false, false)
+	ui.SetIgnoreDirPaths([]string{"/xxx"})
+	err := ui.AnalyzePath("aaa", nil)
+
+	assert.Contains(t, err.Error(), "no such file or directory")
+}
+
 func TestAnalyzePathWithColors(t *testing.T) {
 	fin := testdir.CreateTestDir()
 	defer fin()
@@ -36,8 +71,9 @@ func TestAnalyzePathWithColors(t *testing.T) {
 
 	ui := CreateStdoutUI(output, true, false, true)
 	ui.SetIgnoreDirPaths([]string{"/xxx"})
-	ui.AnalyzePath("test_dir/nested", analyze.ProcessDir, nil)
+	err := ui.AnalyzePath("test_dir/nested", nil)
 
+	assert.Nil(t, err)
 	assert.Contains(t, output.String(), "subnested")
 }
 
@@ -45,8 +81,11 @@ func TestItemRows(t *testing.T) {
 	output := bytes.NewBuffer(make([]byte, 10))
 
 	ui := CreateStdoutUI(output, false, true, false)
-	ui.AnalyzePath("test_dir", testanalyze.MockedProcessDir, nil)
+	ui.Analyzer = &testanalyze.MockedAnalyzer{}
+	ui.PathChecker = testdir.MockedPathChecker
+	err := ui.AnalyzePath("test_dir", nil)
 
+	assert.Nil(t, err)
 	assert.Contains(t, output.String(), "TiB")
 	assert.Contains(t, output.String(), "GiB")
 	assert.Contains(t, output.String(), "MiB")
@@ -61,8 +100,9 @@ func TestAnalyzePathWithProgress(t *testing.T) {
 
 	ui := CreateStdoutUI(output, false, true, true)
 	ui.SetIgnoreDirPaths([]string{"/xxx"})
-	ui.AnalyzePath("test_dir", analyze.ProcessDir, nil)
+	err := ui.AnalyzePath("test_dir", nil)
 
+	assert.Nil(t, err)
 	assert.Contains(t, output.String(), "nested")
 }
 
@@ -70,8 +110,9 @@ func TestShowDevices(t *testing.T) {
 	output := bytes.NewBuffer(make([]byte, 10))
 
 	ui := CreateStdoutUI(output, false, true, false)
-	ui.ListDevices(getDevicesInfoMock())
+	err := ui.ListDevices(getDevicesInfoMock())
 
+	assert.Nil(t, err)
 	assert.Contains(t, output.String(), "Device")
 	assert.Contains(t, output.String(), "xxx")
 }
@@ -80,32 +121,23 @@ func TestShowDevicesWithColor(t *testing.T) {
 	output := bytes.NewBuffer(make([]byte, 10))
 
 	ui := CreateStdoutUI(output, true, true, true)
-	ui.ListDevices(getDevicesInfoMock())
+	err := ui.ListDevices(getDevicesInfoMock())
 
+	assert.Nil(t, err)
 	assert.Contains(t, output.String(), "Device")
 	assert.Contains(t, output.String(), "xxx")
 }
 
-func TestShowDevicesWithErr(t *testing.T) {
-	output := bytes.NewBuffer(make([]byte, 10))
-
-	getter := device.LinuxDevicesInfoGetter{MountsPath: "/xyzxyz"}
-	ui := CreateStdoutUI(output, false, true, false)
-	err := ui.ListDevices(getter)
-
-	assert.Contains(t, err.Error(), "no such file")
-}
-
 func TestMaxInt(t *testing.T) {
 	assert.Equal(t, 5, maxInt(2, 5))
 	assert.Equal(t, 4, maxInt(4, 2))
 }
 
-func printBuffer(buff *bytes.Buffer) {
-	for i, x := range buff.String() {
-		println(i, string(x))
-	}
-}
+// func printBuffer(buff *bytes.Buffer) {
+// 	for i, x := range buff.String() {
+// 		println(i, string(x))
+// 	}
+// }
 
 func getDevicesInfoMock() device.DevicesInfoGetter {
 	item := &device.Device{
